@@ -6,7 +6,8 @@ from ocp_resources.resource import Resource
 
 class DNS(Resource):
     """
-       DNS holds cluster-wide information about DNS. The canonical name is `cluster`
+        DNS holds cluster-wide information about DNS. The canonical name is `cluster`
+
     Compatibility level 1: Stable within a major release for a minimum of 12 months or 3 minor releases (whichever is longer).
     """
 
@@ -23,9 +24,9 @@ class DNS(Resource):
         """
         Args:
             base_domain (str): baseDomain is the base domain of the cluster. All managed DNS records
-              will be sub-domains of this base.   For example, given the base
+              will be sub-domains of this base.  For example, given the base
               domain `openshift.example.com`, an API server DNS record may be
-              created for `cluster-api.openshift.example.com`.   Once set, this
+              created for `cluster-api.openshift.example.com`.  Once set, this
               field cannot be changed.
 
             platform (Dict[str, Any]): platform holds configuration specific to the underlying infrastructure
@@ -34,13 +35,13 @@ class DNS(Resource):
               defaults are subject to change over time.
 
             private_zone (Dict[str, Any]): privateZone is the location where all the DNS records that are only
-              available internally to the cluster exist.   If this field is nil,
-              no private records should be created.   Once set, this field
-              cannot be changed.
+              available internally to the cluster exist.  If this field is nil,
+              no private records should be created.  Once set, this field cannot
+              be changed.
 
             public_zone (Dict[str, Any]): publicZone is the location where all the DNS records that are publicly
-              accessible to the internet exist.   If this field is nil, no
-              public records should be created.   Once set, this field cannot be
+              accessible to the internet exist.  If this field is nil, no public
+              records should be created.  Once set, this field cannot be
               changed.
 
         """
@@ -54,7 +55,7 @@ class DNS(Resource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res["spec"] = {}
             _spec = self.res["spec"]
 
